#[repr(u8)]pub enum ChachaCoreMatrixLbeOrder {
DEFAULT = 0,
REVERSE = 1,
}Variants
DEFAULT = 0
Use default quarter of matrix order, where quarters are ordered as follows: q0, q1, q2, q3. Each quarter represents a 128-bits section of the matrix.
REVERSE = 1
Reverse the order of matrix quarters, where quarters are re-ordered as follows: q3, q2, q1, q0. Each quarter represents a 128-bits section of the matrix.
Implementations